build_config_files_with_bus

Function build_config_files_with_bus 

pub fn build_config_files_with_bus(
    content_map: &HashMap<String, String>,
    skills: &[AgentSkill],
    agent_name: &str,
    agent_id: &str,
    agent_bus_id: &str,
    working_directory: &str,
) -> Vec<AgentConfigFile>
Build the list of config files with a known agent_bus_id.

Same as build_config_files but also accepts an agent_bus_id so the MCP server entry can include AGENTMUX_AGENT_BUS_ID. Prefer this overload when the caller has the full AgentDefinition available.