clear_local_current_zone

Function clear_local_current_zone 

fn clear_local_current_zone(filestore: &FileStore, zone: &str)
Delete output.state.json + output from a per-channel :current zone, only for files that are present (so absence isn’t logged as an error). Best-effort — used after the global-preferred archive has persisted the content, to retire this channel’s (subset) copy.