write_zone_file

Function write_zone_file 

fn write_zone_file(
    filestore: &FileStore,
    zone: &str,
    name: &str,
    content: &[u8],
) -> Result<(), String>
Write the entire contents of a file in zone. Creates the file if missing, otherwise replaces all parts atomically (FileStore single-tx).