pub fn register_controller(block_id: &str, controller: Arc<dyn Controller>)Expand description
Register a controller, stopping any previous one for the same block.
pub fn register_controller(block_id: &str, controller: Arc<dyn Controller>)Register a controller, stopping any previous one for the same block.