pub fn load_settings_from_disk(config_watcher: &ConfigWatcher)Expand description
Load settings.json from disk into the ConfigWatcher. Called once at startup so the backend has the user’s saved settings.
pub fn load_settings_from_disk(config_watcher: &ConfigWatcher)Load settings.json from disk into the ConfigWatcher. Called once at startup so the backend has the user’s saved settings.