pub fn get_path(
data: &Value,
path: &Vec<PathElement>,
) -> Result<Option<Value>, IJsonError>Expand description
Get a value at the specified path within JSON data.
Returns None if the path doesn’t exist (not an error).
pub fn get_path(
data: &Value,
path: &Vec<PathElement>,
) -> Result<Option<Value>, IJsonError>Get a value at the specified path within JSON data.
Returns None if the path doesn’t exist (not an error).