pub type Path = Vec<PathElement>;Expand description
A JSON path is a sequence of string keys and integer indices.
Example: ["users", 0, "name"] → data.users[0].name
Aliased Type
pub struct Path { /* private fields */ }pub type Path = Vec<PathElement>;A JSON path is a sequence of string keys and integer indices.
Example: ["users", 0, "name"] → data.users[0].name
pub struct Path { /* private fields */ }