pub fn lookup(data_dir: &Path, agent_id: &str) -> Option<AgentEntry>Expand description
Look up an agent entry. Returns None if not found or file is malformed.
pub fn lookup(data_dir: &Path, agent_id: &str) -> Option<AgentEntry>Look up an agent entry. Returns None if not found or file is malformed.