WshRouter

Struct WshRouter 

pub struct WshRouter {
    inner: Mutex<RouterInner>,
    input_tx: Sender<MsgAndRoute>,
}
RPC message router. Acts like a network switch, routing messages between multiple named endpoints based on route IDs.

Port of Go’s WshRouter from pkg/wshutil/wshrouter.go.

Fields

inner: Mutex<RouterInner>input_tx: Sender<MsgAndRoute>

Implementations

Source

impl WshRouter

pub fn new() -> Arc<Self>

Create a new router and spawn the background message loop.

pub fn inject_message(&self, msg_bytes: Vec<u8>, from_route_id: &str)

Inject a message into the router from a given route.

pub fn register_route(&self, route_id: &str, client: Box<dyn RpcClient>)

Register a route with the router.

pub fn unregister_route(&self, route_id: &str)

Unregister a route from the router.

pub fn has_route(&self, route_id: &str) -> bool

Check if a route is registered.

pub fn route_ids(&self) -> Vec<String>

Get all registered route IDs.

pub async fn wait_for_register(&self, route_id: &str, timeout: Duration) -> bool

Wait for a route to be registered (with timeout).

pub async fn run_simple_raw_command( &self, msg: RpcMessage, from_route_id: &str, timeout: Duration, ) -> Result<Option<RpcMessage>, String>

Run a simple request through the router and wait for a single response.

fn register_route_info( &self, rpc_id: &str, source_route_id: &str, dest_route_id: &str, )

fn unregister_route_info(&self, rpc_id: &str)

fn get_route_info(&self, rpc_id: &str) -> Option<RouteInfo>

fn send_routed_message(&self, msg_bytes: &[u8], route_id: &str) -> bool

fn handle_no_route(&self, msg: &RpcMessage)

fn handle_announce_message(&self, msg: &RpcMessage, from_route_id: &str)

fn handle_unannounce_message(&self, msg: &RpcMessage)

fn register_simple_request(&self, req_id: &str) -> Receiver<RpcMessage>

fn try_simple_response(&self, msg: &RpcMessage) -> bool

fn clear_simple_request(&self, req_id: &str)

async fn run_server(&self, input_rx: Receiver<MsgAndRoute>)