resolve_schema_path

Function resolve_schema_path 

pub fn resolve_schema_path(base_dir: &Path, name: &str) -> Option<PathBuf>
Resolve a schema file path, trying the exact path first, then with .json extension.

Returns Some(path) if a file exists at the exact path or with .json appended. Returns None if neither exists.