get_optional_arg

Function get_optional_arg 

pub fn get_optional_arg<T: DeserializeOwned>(
    args: &[Value],
    idx: usize,
) -> Result<Option<T>, String>
Extract an optional typed argument from the args array. Returns Ok(None) if the index is out of bounds or the value is null.