fn get_interval_secs(config_watcher: &ConfigWatcher) -> f64Expand description
Read the telemetry interval from config, clamped to [MIN, MAX].
fn get_interval_secs(config_watcher: &ConfigWatcher) -> f64Read the telemetry interval from config, clamped to [MIN, MAX].