run_sysinfo_loop

Function run_sysinfo_loop 

pub async fn run_sysinfo_loop(
    broker: Arc<Broker>,
    config_watcher: Arc<ConfigWatcher>,
    conn_name: String,
)
Run the sysinfo collection loop. Uses tokio::time::interval for steady tick rate regardless of refresh duration. Interval is re-read from config each tick and the timer is reset if it changes.