safe_join

Function safe_join 

pub fn safe_join(base: &Path, name: &str) -> Result<PathBuf, TarCopyError>
Construct a destination path from a base directory and tar entry name. Ensures the resulting path is within the base directory.