pub struct ToolSpec {
pub id: String,
pub display: String,
pub description: String,
pub tier: u8,
pub version: String,
pub check_cmd: String,
pub version_arg: Option<String>,
pub bundled: bool,
pub platforms: HashMap<String, PlatformSpec>,
}Fields
id: Stringdisplay: Stringdescription: Stringtier: u8version: Stringcheck_cmd: Stringversion_arg: Option<String>Flag (e.g. "--version") to pass to the binary to get its version string.
If absent, version probing is skipped and the catalog version is reported.
bundled: boolplatforms: HashMap<String, PlatformSpec>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ToolSpec
impl<'de> Deserialize<'de> for ToolSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more