build_default_config

Function build_default_config 

pub fn build_default_config() -> FullConfigType
Build the initial default configuration with embedded default assets.

Loads the bundled widgets.json (from config/) at compile time and populates FullConfigType.widgets so the frontend widget bar is populated on startup.