promote_block_to_tab

Function promote_block_to_tab 

pub fn promote_block_to_tab(
    store: &WaveStore,
    block_id: &str,
    source_tab_id: &str,
    ws_id: &str,
    auto_close_source: bool,
) -> Result<Tab, StoreError>
Promote a block to a new tab. Removes the block from source_tab_id, creates a new tab in ws_id, and adds the block to the new tab. Returns the new Tab. If auto_close_source is true, deletes the source tab when it becomes empty.