tear_off_block

Function tear_off_block 

pub fn tear_off_block(
    store: &WaveStore,
    block_id: &str,
    source_tab_id: &str,
    source_ws_id: &str,
    auto_close_source: bool,
) -> Result<Workspace, StoreError>
Tear off a block into a new workspace. Removes the block from source_tab_id, creates a new workspace with a single tab containing the block. Returns the new workspace. If auto_close_source is true, deletes the source tab when it becomes empty.