tear_off_tab

Function tear_off_tab 

pub fn tear_off_tab(
    store: &WaveStore,
    tab_id: &str,
    source_ws_id: &str,
) -> Result<Workspace, StoreError>
Tear off a tab into a new workspace. Removes the tab from the source workspace and creates a new workspace containing just that tab. Returns the new workspace. The source workspace must have more than one tab.