ensure_initial_data

Function ensure_initial_data 

pub fn ensure_initial_data(store: &WaveStore) -> Result<bool, StoreError>
Ensure initial data is present in the store. Creates a default Client, Window, Workspace, Tab if the store is empty. Returns true if this is a first launch (client was just created).