bound_providers

Function bound_providers 

fn bound_providers(wstore: &Arc<WaveStore>) -> HashSet<String>
Collect the set of providers that are bound in ANY identity bundle today. The migration’s idempotency gate — if a provider is already in here, the ambient-creds seed is a no-op for that provider.