infer_provider_from_model

Function infer_provider_from_model 

fn infer_provider_from_model(model: &str) -> String
Create a stub AgentInstance for a definition, idempotently.

The stub id is deterministically derived from the definition id so that calling this function multiple times for the same definition is a no-op rather than accumulating duplicate stopped rows in My Agents. Infer a provider slug from a model name prefix. Only maps prefixes that correspond to a registered provider slug. Callers must still validate the result via providers::get_provider.