async fn finish_name_call(
state: &AppState,
call: WebCallType,
ok_body: Value,
) -> ResponseExpand description
Run a naming service call and map the result to a JSON HTTP response.
async fn finish_name_call(
state: &AppState,
call: WebCallType,
ok_body: Value,
) -> ResponseRun a naming service call and map the result to a JSON HTTP response.