dispatch_to_reducer

Function dispatch_to_reducer 

pub(crate) async fn dispatch_to_reducer(
    state: &AppState,
    cmd: Command,
) -> Vec<Event>
Dispatch a command into the srv reducer and return the emitted events. Locks the reducer mutex briefly; the lock is released before any I/O (caller is responsible for publishing the events to the broadcast bus).