fn reseed_if_needed(
wstore: &Arc<WaveStore>,
manifest: &SeedManifest,
) -> Result<Option<ReseedReport>, StoreError>Expand description
Re-seed if the manifest version is newer than what’s in the DB. Updates seeded agents, adds new ones, removes seeded agents not in the manifest.