struct SeedMemory {
id: String,
name: String,
description: String,
is_global: bool,
instructions: String,
}Expand description
A memory bundle in the seed manifest.
Fields
id: Stringname: Stringdescription: Stringis_global: boolWhen true this bundle is injected into every agent’s CLAUDE.md at launch (Trust Center global tier). When false it is available in the Memory manager but must be selected per-agent.
instructions: StringTrait Implementations
Sourceimpl Debug for SeedMemory
impl Debug for SeedMemory
Sourceimpl<'de> Deserialize<'de> for SeedMemory
impl<'de> Deserialize<'de> for SeedMemory
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more