pub fn clear_tree_node(_root: &mut Option<LayoutNode>)Expand description
Clear the tree root. Callers set the Option<LayoutNode> to None.
This function exists only to be referenced in the test helper pattern;
actual clearing in the reducer just sets root = None.