pub fn build_default_config() -> FullConfigTypeExpand description
Build the initial default configuration with embedded default assets.
Loads the bundled widgets.json (from config/) at compile time
and populates FullConfigType.widgets so the frontend widget bar is populated on startup.