pub async fn run(
state: &AppState,
block_id: String,
source_tab_id: String,
source_workspace_id: String,
target_tab_id: String,
target_workspace_id: String,
dst_index: Option<u32>,
) -> Result<Value, String>Expand description
Run the RedockFloatingPane saga. On success, returns
{ "block_id": "...", "target_tab_id": "..." }.
dst_index defaults to the end of the target tab’s blockids if
callers don’t have a specific drop position (Phase 4a MVP). Phase
4b polish will let callers specify a drop position relative to a
target leaf + direction (left/right/top/bottom/into).